feat(1.103): update patches (#2437)

This commit is contained in:
Baptiste Augrain
2025-07-29 14:55:09 +02:00
committed by GitHub
parent c31bc7e230
commit 067a4d4e7d
7 changed files with 38 additions and 28 deletions

View File

@@ -745,7 +745,7 @@ index e214bf7..efb48d6 100644
+ localize('appName', "`${appName}`: e.g. !!APP_NAME!!."),
localize('remoteName', "`${remoteName}`: e.g. SSH"),
diff --git a/src/vs/workbench/contrib/chat/browser/chatSetup.ts b/src/vs/workbench/contrib/chat/browser/chatSetup.ts
index f0afc65..96f6944 100644
index 5ebe9c1..ff02d8b 100644
--- a/src/vs/workbench/contrib/chat/browser/chatSetup.ts
+++ b/src/vs/workbench/contrib/chat/browser/chatSetup.ts
@@ -140,3 +140,3 @@ class SetupAgent extends Disposable implements IChatAgentImplementation {
@@ -825,15 +825,15 @@ index 1fc3f63..c1f8609 100644
+ this.updateStatus({ icon: warningIcon, message: new MarkdownString(localize('deprecated with alternate settings tooltip', "This extension is deprecated as this functionality is now built-in to !!APP_NAME!!. Configure these {0} to use this functionality.", link)) }, true);
} else {
diff --git a/src/vs/workbench/contrib/welcomeGettingStarted/common/gettingStartedContent.ts b/src/vs/workbench/contrib/welcomeGettingStarted/common/gettingStartedContent.ts
index 6815074..0da92bf 100644
index ac2672d..0da92bf 100644
--- a/src/vs/workbench/contrib/welcomeGettingStarted/common/gettingStartedContent.ts
+++ b/src/vs/workbench/contrib/welcomeGettingStarted/common/gettingStartedContent.ts
@@ -210,13 +210,2 @@ export const startEntries: GettingStartedStartEntryContent = [
},
- {
- id: 'topLevelNewWorkspaceChat',
- title: localize('gettingStarted.newWorkspaceChat.title', "New Workspace with Copilot..."),
- description: localize('gettingStarted.newWorkspaceChat.description', "Create a new workspace with Copilot"),
- icon: Codicon.copilot,
- title: localize('gettingStarted.newWorkspaceChat.title', "Generate New Workspace..."),
- description: localize('gettingStarted.newWorkspaceChat.description', "Chat to create a new workspace"),
- icon: Codicon.chatSparkle,
- when: '!isWeb && !chatSetupHidden',
- content: {
- type: 'startEntry',

View File

@@ -1,17 +0,0 @@
diff --git a/build/gulpfile.vscode.win32.js b/build/gulpfile.vscode.win32.js
index 4a9a644..45c1e2b 100644
--- a/build/gulpfile.vscode.win32.js
+++ b/build/gulpfile.vscode.win32.js
@@ -114,7 +114,7 @@ function buildWin32Setup(arch, target) {
- if (quality === 'insider') {
- definitions['AppxPackage'] = `code_insiders_explorer_${arch}.appx`;
- definitions['AppxPackageFullname'] = `Microsoft.${product.win32RegValueName}_1.0.0.0_neutral__8wekyb3d8bbwe`;
- definitions['AppxPackageName'] = `Microsoft.${product.win32RegValueName}`;
- }
+ // if (quality === 'insider') {
+ // definitions['AppxPackage'] = `code_insiders_explorer_${arch}.appx`;
+ // definitions['AppxPackageFullname'] = `Microsoft.${product.win32RegValueName}_1.0.0.0_neutral__8wekyb3d8bbwe`;
+ // definitions['AppxPackageName'] = `Microsoft.${product.win32RegValueName}`;
+ // }

View File

@@ -0,0 +1,12 @@
diff --git a/build/gulpfile.vscode.js b/build/gulpfile.vscode.js
index 25d8916..11336b7 100644
--- a/build/gulpfile.vscode.js
+++ b/build/gulpfile.vscode.js
@@ -417,5 +417,5 @@ function packageTask(platform, arch, sourceFolderName, destinationFolderName, op
.pipe(replace('@@ApplicationExe@@', product.nameShort + '.exe'))
- .pipe(replace('@@FileExplorerContextMenuID@@', quality === 'stable' ? 'OpenWithCode' : 'OpenWithCodeInsiders'))
+ .pipe(replace('@@FileExplorerContextMenuID@@', `OpenWith${product.win32RegValueName}`))
.pipe(replace('@@FileExplorerContextMenuCLSID@@', product.win32ContextMenu[arch].clsid))
- .pipe(replace('@@FileExplorerContextMenuDLL@@', `${quality === 'stable' ? 'code' : 'code_insider'}_explorer_command_${arch}.dll`))
+ .pipe(replace('@@FileExplorerContextMenuDLL@@', `${product.applicationName.replace(/-/g, '_')}_explorer_command_${arch}.dll`))
.pipe(rename(f => f.dirname = `appx/manifest`)));

View File

@@ -0,0 +1,9 @@
diff --git a/build/gulpfile.vscode.win32.js b/build/gulpfile.vscode.win32.js
index 643bf54..d7950a0 100644
--- a/build/gulpfile.vscode.win32.js
+++ b/build/gulpfile.vscode.win32.js
@@ -115,3 +115,3 @@ function buildWin32Setup(arch, target) {
if (quality !== 'exploration') {
- definitions['AppxPackage'] = `${quality === 'stable' ? 'code' : 'code_insider'}_${arch}.appx`;
+ definitions['AppxPackage'] = `${product.applicationName.replace(/-/g, '_')}_${arch}.appx`;
definitions['AppxPackageName'] = `${product.win32AppUserModelId}`;

View File

@@ -100,7 +100,7 @@ mv .npmrc.bak .npmrc
setpath() {
local jsonTmp
{ set +x; } 2>/dev/null
jsonTmp=$( jq --arg 'path' "${2}" --arg 'value' "${3}" 'setpath([$path]; $value)' "${1}.json" )
jsonTmp=$( jq --arg 'value' "${3}" "setpath(path(.${2}); \$value)" "${1}.json" )
echo "${jsonTmp}" > "${1}.json"
set -x
}
@@ -108,7 +108,7 @@ setpath() {
setpath_json() {
local jsonTmp
{ set +x; } 2>/dev/null
jsonTmp=$( jq --arg 'path' "${2}" --argjson 'value' "${3}" 'setpath([$path]; $value)' "${1}.json" )
jsonTmp=$( jq --argjson 'value' "${3}" "setpath(path(.${2}); \$value)" "${1}.json" )
echo "${jsonTmp}" > "${1}.json"
set -x
}
@@ -167,6 +167,8 @@ if [[ "${VSCODE_QUALITY}" == "insider" ]]; then
setpath "product" "tunnelApplicationName" "codium-tunnel-insiders"
setpath "product" "win32TunnelServiceMutex" "vscodiuminsiders-tunnelservice"
setpath "product" "win32TunnelMutex" "vscodiuminsiders-tunnel"
setpath "product" "win32ContextMenu.x64.clsid" "90AAD229-85FD-43A3-B82D-8598A88829CF"
setpath "product" "win32ContextMenu.arm64.clsid" "7544C31C-BDBF-4DDF-B15E-F73A46D6723D"
else
setpath "product" "nameShort" "VSCodium"
setpath "product" "nameLong" "VSCodium"
@@ -192,6 +194,8 @@ else
setpath "product" "tunnelApplicationName" "codium-tunnel"
setpath "product" "win32TunnelServiceMutex" "vscodium-tunnelservice"
setpath "product" "win32TunnelMutex" "vscodium-tunnel"
setpath "product" "win32ContextMenu.x64.clsid" "D910D5E6-B277-4F4A-BDC5-759A34EEE25D"
setpath "product" "win32ContextMenu.arm64.clsid" "4852FC55-4A84-4EA1-9C86-D53BE3DF83C0"
fi
jsonTmp=$( jq -s '.[0] * .[1]' product.json ../product.json )

View File

@@ -202,6 +202,8 @@
"contribMultiDiffEditorMenus",
"contribShareMenu",
"diffCommand",
"languageModelDataPart",
"languageModelToolResultAudience",
"quickDiffProvider",
"remoteCodingAgents",
"shareProvider",

View File

@@ -1,4 +1,4 @@
{
"tag": "1.103.0",
"commit": "d8361fecca3b53536de8f7a949b107fb7451e5e6"
"commit": "4968600c8228730f6256de900c42900297e90b46"
}
diff --git a/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts b/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
index ffe36f4..d7ebb5d 100644
index 9927c14..c117131 100644
--- a/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
+++ b/src/vs/workbench/contrib/extensions/browser/extensionsWorkbenchService.ts
@@ -476,3 +476,3 @@ export class Extension implements IExtension {
@@ -477,3 +477,3 @@ export class Extension implements IExtension {
return Promise.resolve(`# ${this.displayName || this.name}
**Notice:** This extension is bundled with Visual Studio Code. It can be disabled but not uninstalled.
## Features
@@ -514,3 +514,3 @@ ${this.description}
@@ -515,3 +515,3 @@ ${this.description}
if (this.type === ExtensionType.System) {
- return Promise.resolve(`Please check the [VS Code Release Notes](command:${ShowCurrentReleaseNotesActionId}) for changes to the built-in extensions.`);
+ return Promise.resolve(`Please check the [!!APP_NAME!! Release Notes](command:${ShowCurrentReleaseNotesActionId}) for changes to the built-in extensions.`);
@@ -1067,16 +1067,16 @@ index 3f1c098..26bf670 100644
+ description: localize('walkthroughs.steps.completionEvents.onCommand', 'Check off step when a given command is executed anywhere in !!APP_NAME!!.'),
body: 'onCommand:${1:commandId}'
@@ -477,3 +477,3 @@ export class Extension implements IExtension {
return Promise.resolve(`# ${this.displayName || this.name}
-**Notice:** This extension is bundled with Visual Studio Code. It can be disabled but not uninstalled.
+**Notice:** This extension is bundled with !!APP_NAME!!. It can be disabled but not uninstalled.
## Features